from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("asymmetric_jwt_auth", "0002_publickey_comment"),
    ]

    operations = [
        migrations.AlterField(
            model_name="publickey",
            name="comment",
            field=models.CharField(blank=True, max_length=100, help_text="Comment describing this key"),
        ),
    ]



from django.contrib import admin
from django.urls import include, path

urlpatterns = [
    path("i18n/", include("django.conf.urls.i18n")),
    path("admin/", admin.site.urls),
    path("", include("asymmetric_jwt_auth.urls")),
]



import os

BASE_DIR = os.path.dirname(os.path.abspath(__file__))

DEBUG = True
SECRET_KEY = "li0$-gnv)76g$yf7p@(cg-^_q7j6df5cx$o-gsef5hd68phj!4"
SITE_ID = 1
ROOT_URLCONF = "urls"

INSTALLED_APPS = [
    "django.contrib.admin",
    "django.contrib.auth",
    "django.contrib.contenttypes",
    "django.contrib.sessions",
    "django.contrib.sites",
    "django.contrib.messages",
    "asymmetric_jwt_auth",
]

MIDDLEWARE = [
    "django.middleware.security.SecurityMiddleware",
    "django.contrib.sessions.middleware.SessionMiddleware",
    "django.middleware.locale.LocaleMiddleware",
    "django.middleware.common.CommonMiddleware",
    "django.middleware.csrf.CsrfViewMiddleware",
    "django.contrib.auth.middleware.AuthenticationMiddleware",
    "django.contrib.messages.middleware.MessageMiddleware",
    "django.middleware.clickjacking.XFrameOptionsMiddleware",
]

DEFAULT_AUTO_FIELD = "django.db.models.AutoField"
DATABASES = {
    "default": {
        "ENGINE": "django.db.backends.sqlite3",
        "NAME": ":memory:",
    }
}

CACHES = {
    "default": {
        "BACKEND": "django.core.cache.backends.locmem.LocMemCache",
        "LOCATION": "jwt-testing-sandbox",
    }
}

TEMPLATES = [
    {
        "BACKEND": "django.template.backends.django.DjangoTemplates",
        "DIRS": [],
        "APP_DIRS": True,
        "OPTIONS": {
            "context_processors": [
                "django.template.context_processors.debug",
                "django.template.context_processors.request",
                "django.contrib.auth.context_processors.auth",
                "django.contrib.messages.context_processors.messages",
            ],
        },
    },
]

LOGGING = {
    "version": 1,
    "disable_existing_loggers": False,
    "formatters": {
        "cmdline": {
            "format": "%(name)s: %(levelname)s %(message)s",
            "datefmt": "%Y-%m-%dT%H:%M:%S",
        },
    },
    "handlers": {
        "console": {
            "level": "DEBUG",
            "class": "logging.StreamHandler",
            "formatter": "cmdline",
        },
    },
    "root": {
        "handlers": ["console"],
        "level": "DEBUG",
    },
}



from django.contrib.auth.models import User

from ..tokens import Token, UntrustedToken


class BaseUserRepository:
    def get_user(self, username: str) -> None | User:  # pragma: no cover
        raise NotImplementedError()


class BasePublicKeyRepository:
    def attempt_to_verify_token(self, user: User, untrusted_token: UntrustedToken) -> Token | None:  # pragma: no cover
        raise NotImplementedError()



import secrets


class BaseNonceBackend:
    def validate_nonce(self, username: str, timestamp: int, nonce: str) -> bool:  # pragma: no cover
        raise NotImplementedError()

    def log_used_nonce(self, username: str, timestamp: int, nonce: str) -> None:  # pragma: no cover
        raise NotImplementedError()

    def generate_nonce(self) -> str:
        return secrets.token_urlsafe(nbytes=8)
